

export const index = 9;
let component_cache;
export const component = async () => component_cache ??= (await import('../entries/pages/(app)/admin/_page.svelte.js')).default;
export const imports = ["_app/immutable/nodes/9.UTtm07pn.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/BY-rXZ0_.js"];
export const stylesheets = [];
export const fonts = [];
